@@ -65,7 +65,10 @@ def add(ctx, user_name, policies_string):
             ret = svc.add_user_to_project(user_name=user_name)
     except ProjectError as ex:
         abort(ex)
-    click.secho(f"User {user_name} has been added to project {ret['project']} with roles {', '.join(ret['policies'])}", bold=True)
+    click.secho(
+        f"User {user_name} has been added to project {ret['project']} with roles {', '.join(ret['policies'])}",
+        bold=True,
+    )
 
 
 @users.command()
