@@ -61,6 +61,7 @@ log = logging.getLogger(__name__)
 @option('-c', '--credentials', help="Credentials to forward to workflow-service", multiple=True)
 @option('--executor_memory_mb', help='Override the memory limit of the nextflow executor')
 @option('--scheduler_name', help="Overrides the scheduler to use for the run")
+@option('-e', '--features', help="Extra parameters to pass to workflow-service to turn features on/off", multiple=True)
 @pass_context
 def run(
     ctx,
@@ -83,6 +84,7 @@ def run(
     credentials,
     executor_memory_mb,
     scheduler_name,
+    features
 ):
     """
     Start a new nextflow job.
@@ -112,6 +114,8 @@ def run(
             credentials_map = manifest.get('credentials', {})
     credentials_struct = generate_credential_struct(credentials_map)
 
+    features = {f.split('=')[0]:f.split('=')[-1] for f in features}
+
     try:
         override_params = {}
         for p in parameters:
@@ -124,10 +128,11 @@ def run(
         params[k] = v
 
     log.info(
-        "Running pipeline '%s' on project '%s' with parameters %s",
+        "Running pipeline '%s' on project '%s' with parameters %s and features %s",
         pipeline_name,
         project_name,
         dict(params),
+        dict(features)
     )
 
     if mount_job:
@@ -181,6 +186,7 @@ def run(
             mount_jobs=mount_job,
             executor_memory_mb=int(executor_memory_mb) if executor_memory_mb else None,
             scheduler_name=scheduler_name,
+            features=features
         )
     except ServerError as e:
         abort(str(e))
